
#line 3 "lexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 39
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 89
#define YY_END_OF_BUFFER 90
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_acclist[368] =
    {   0,
       90,   88,   89,   74,   88,   89,   73,   89,   74,   88,
       89,   84,   88,   89,   88,   89,   88,   89,   85,   88,
       89,   84,   88,   89,   56,   88,   89,   58,   88,   89,
       85,   86,   88,   89,   71,   85,   88,   89,   71,   85,
       88,   89,   71,   85,   88,   89,   85,   88,   89,   11,
       85,   88,   89,   19,   85,   88,   89,   21,   85,   88,
       89,   20,   85,   88,   89,   85,   88,   89,   59,   85,
       88,   89,   54,   85,   88,   89,   85,   88,   89,   55,
       85,   88,   89,   59,   88,   89,   59,   88,   89,   59,
       88,   89,   59,   88,   89,   59,   88,   89,   59,   88,

       89,   59,   88,   89,   59,   88,   89,   59,   88,   89,
       59,   88,   89,   59,   88,   89,   59,   88,   89,   59,
       88,   89,   59,   88,   89,   59,   88,   89,   59,   88,
       89,   59,   88,   89,   59,   88,   89,   59,   88,   89,
       87,   88,   89,   58,   88,   89,   74,   88,   89,   59,
       88,   89,   59,   88,   89,   59,   88,   89,   59,   88,
       89,   74,   73,   74,   55,   83,   14,   12,    1,   57,
       80,   82,   77,   75,   76,   78,   67,   79,   81,   70,
       71,   71,   61,   71,   61,   71,   22,   17,   15,   13,
       18,   52,   59,   54,   72,   59,   59,   59,   36,   59,

       59,   59,   34,   59,   59,   59,   59,   59,   38,   59,
       37,   59,   59,   59,   59,   59,   28,   59,   59,   59,
       59,   59,   59,   59,   35,   59,   59,   59,   59,   74,
       59,   59,   59,   59,   59,   59,   12,   53,   64,   66,
       69,   68,   16,   26,   59,   59,   59,   59,   59,   59,
       59,   31,   59,   59,   59,   59,   49,   59,   25,   59,
       59,   59,   59,   59,   32,   59,   59,   59,   59,   59,
       27,   59,   59,   59,    8,   59,   59,   65,   63,   59,
       59,   43,   59,   59,   40,   59,   59,   59,   59,   59,
       50,   59,   59,   33,   59,   59,   59,   39,   59,   59,

       59,   59,   59,   59,    6,   62,   60,   59,   48,   59,
       59,   59,   59,   59,   51,   59,   59,   59,   59,   30,
       59,   29,   59,    4,   10,    7,   59,   60,   60,   59,
       59,   59,   59,   59,   59,   44,   59,   59,   59,   45,
       59,   59,   59,   59,   59,   59,   59,    9,    3,   47,
       59,   59,   41,   59,   59,   59,   23,   59,    2,    3,
       46,   59,   24,   59,   42,   59,    5
    } ;

static yyconst flex_int16_t yy_accept[291] =
    {   0,
        1,    1,    1,    2,    4,    7,    9,   12,   15,   17,
       19,   22,   25,   28,   31,   35,   39,   43,   47,   50,
       54,   58,   62,   66,   69,   73,   77,   80,   84,   87,
       90,   93,   96,   99,  102,  105,  108,  111,  114,  117,
      120,  123,  126,  129,  132,  135,  138,  141,  144,  147,
      150,  153,  156,  159,  162,  163,  164,  165,  166,  167,
      168,  168,  169,  169,  169,  170,  170,  171,  172,  173,
      174,  175,  176,  176,  177,  178,  179,  180,  180,  182,
      183,  183,  184,  184,  184,  185,  185,  186,  187,  188,
      189,  190,  191,  192,  193,  194,  195,  196,  197,  198,

      199,  201,  202,  203,  205,  206,  207,  208,  209,  211,
      213,  214,  215,  216,  217,  219,  220,  221,  222,  223,
      224,  225,  227,  228,  229,  230,  231,  231,  231,  231,
      231,  232,  233,  234,  235,  236,  237,  238,  239,  239,
      240,  240,  241,  242,  242,  243,  244,  246,  247,  248,
      249,  250,  251,  252,  254,  255,  256,  257,  259,  261,
      262,  263,  264,  265,  267,  268,  269,  270,  271,  273,
      273,  273,  273,  273,  273,  273,  273,  274,  275,  275,
      276,  277,  278,  278,  279,  280,  280,  280,  280,  281,
      282,  284,  285,  287,  288,  289,  290,  291,  293,  294,

      296,  297,  298,  300,  301,  302,  302,  302,  302,  302,
      302,  303,  304,  304,  305,  305,  306,  307,  308,  309,
      311,  312,  313,  314,  315,  317,  318,  319,  320,  322,
      324,  324,  324,  324,  324,  325,  325,  326,  326,  326,
      327,  328,  329,  330,  331,  332,  333,  334,  335,  336,
      338,  339,  339,  339,  339,  339,  340,  342,  343,  344,
      345,  346,  347,  348,  348,  348,  349,  349,  350,  350,
      350,  350,  350,  352,  353,  355,  356,  357,  359,  359,
      361,  361,  361,  363,  365,  367,  367,  367,  368,  368
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    7,    8,    1,    9,    1,   10,   11,
       12,   13,   14,   15,   16,   17,   18,   19,   20,   20,
       20,   21,   21,   21,   21,   22,   22,   23,   24,   25,
       26,   27,   15,   28,   29,   29,   29,   29,   30,   29,
       31,   31,   31,   31,   31,   31,   31,   31,   31,   31,
       31,   31,   31,   31,   31,   31,   31,   31,   31,   31,
       32,   33,   34,   35,   36,   15,   37,   38,   39,   40,

       41,   42,   43,   44,   45,   46,   47,   48,   49,   50,
       51,   52,   46,   53,   54,   55,   56,   46,   57,   58,
       59,   46,   60,   61,   62,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[63] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    3,    3,
        3,    3,    1,    1,    1,    1,    1,    1,    3,    3,
        4,    1,    1,    1,    1,    5,    3,    3,    3,    3,
        3,    3,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    1,
        1,    1
    } ;

static yyconst flex_int16_t yy_base[306] =
    {   0,
        0,   61,  551,  552,   65,  552,   69,   58,   58,  547,
      552,  552,  552,   70,  107,  126,  180,   57,  523,  552,
       54,  522,  521,  535,    0,   80,  542,  552,  494,   49,
       46,  492,   40,   36,    0,   51,  491,  490,   38,  487,
       53,  498,   39,   59,  488,  493,  485,  552,  552,  129,
       67,  494,   60,   82,  148,  552,  153,  552,  552,  552,
      105,  552,  129,  531,  552,  159,  552,  552,  552,  552,
      552,  552,  516,  552,  196,  552,  552,  167,  210,  226,
      243,  552,    0,  154,    0,    0,  527,  498,  552,  503,
      552,  552,  552,  552,    0,  139,  552,  489,  483,  486,

        0,  478,  475,    0,  470,  484,  469,  471,    0,  481,
      480,  478,  462,  468,    0,  462,  463,  458,  463,  474,
      469,    0,  454,  463,  454,  270,  466,  464,  115,  122,
      178,  456,  153,  191,  447,  462,  158,  552,  262,  552,
      214,  266,    0,  271,    0,  552,    0,  453,  463,  451,
      443,  456,  455,    0,  456,  441,  456,    0,    0,  444,
      454,  450,  433,    0,  436,  437,  441,  437,    0,  193,
      436,  446,  204,  426,  441,  209,  428,  439,  217,  552,
      435,  247,  275,  279,  552,  248,  307,  459,  425,  428,
        0,  429,    0,  421,  417,  430,  422,    0,  420,    0,

      415,  410,    0,  418,  416,  385,  372,  351,  300,  390,
      305,  237,  389,  345,  310,  552,  552,  311,  332,    0,
      337,  331,  339,  334,    0,  341,  331,  335,    0,    0,
      318,  256,  334,  375,  552,  332,  552,  334,  374,  552,
      324,  321,  552,  318,  316,  326,  307,  278,  262,    0,
      251,  229,  263,  257,  335,  275,    0,  212,  193,  178,
      173,  171,  161,  342,  200,  552,  175,  552,  342,  346,
      343,  348,    0,  122,    0,  105,  106,    0,  352,  552,
      358,  146,    0,    0,    0,  362,  134,  552,  552,  395,
      400,  403,  119,  406,  410,  415,  420,  425,  430,  435,

      440,  445,  450,  455,  460
    } ;

static yyconst flex_int16_t yy_def[306] =
    {   0,
      289,    1,  289,  289,  289,  289,  289,  289,  290,  291,
      289,  289,  289,  289,  289,  289,  289,   17,  289,  289,
      289,  289,  289,  289,  292,  289,  289,  289,  292,  292,
      292,  292,  292,  292,  292,  292,  292,  292,  292,  292,
      292,  292,  292,  292,  292,  292,  292,  289,  289,  289,
      292,  292,  292,  292,  289,  289,  289,  289,  289,  289,
      290,  289,  290,  291,  289,  289,  289,  289,  289,  289,
      289,  289,  289,  289,  289,  289,  289,  289,  289,  289,
      289,  289,  293,  289,   18,  294,  289,   18,  289,  289,
      289,  289,  289,  289,  292,  289,  289,  292,  292,  292,

      292,  292,  292,  292,  292,  292,  292,  292,  292,  292,
      292,  292,  292,  292,  292,  292,  292,  292,  292,  292,
      292,  292,  292,  292,  292,  289,  289,  289,  289,  289,
      292,  292,  292,  292,  292,  292,  290,  289,  289,  289,
      289,  289,  293,  289,  294,  289,  292,  292,  292,  292,
      292,  292,  292,  292,  292,  292,  292,  292,  292,  292,
      292,  292,  292,  292,  292,  292,  292,  292,  292,  289,
      289,  289,  289,  289,  289,  295,  292,  292,  296,  289,
      292,  292,  289,  289,  289,  289,  289,  289,  292,  292,
      292,  292,  292,  292,  292,  292,  292,  292,  292,  292,

      292,  292,  292,  292,  292,  289,  289,  289,  289,  297,
      292,  292,  298,  292,  289,  289,  289,  289,  292,  292,
      292,  292,  292,  292,  292,  292,  292,  292,  292,  292,
      289,  289,  289,  297,  289,  299,  289,  300,  298,  289,
      292,  289,  289,  292,  292,  292,  292,  292,  292,  292,
      292,  289,  301,  302,  303,  292,  292,  292,  292,  292,
      292,  292,  292,  289,  301,  289,  302,  289,  303,  302,
      303,  304,  292,  292,  292,  292,  292,  292,  302,  289,
      303,  305,  292,  292,  292,  303,  305,  289,    0,  289,
      289,  289,  289,  289,  289,  289,  289,  289,  289,  289,

      289,  289,  289,  289,  289
    } ;

static yyconst flex_int16_t yy_nxt[615] =
    {   0,
        4,    5,    6,    7,    5,    8,    9,   10,   11,   12,
       13,   14,   11,   11,   11,   11,   15,   11,   16,   17,
       18,   18,   19,   20,   21,   22,   23,   24,   25,   25,
       25,   26,   27,   28,   11,   25,   29,   30,   31,   32,
       33,   34,   35,   35,   36,   35,   35,   37,   38,   39,
       40,   41,   42,   43,   44,   45,   46,   47,   35,   13,
       48,   49,   50,   59,   62,   50,   55,   56,   57,   55,
       57,   66,   57,   57,   66,   88,   88,   88,   88,   90,
       91,   96,  102,   60,   96,   99,  107,  105,  113,  116,
       63,  108,  109,  114,  119,  120,  103,  106,   58,   51,

      110,  100,  121,  102,   52,  117,  131,  101,   53,  122,
      133,   62,   54,  134,   67,   68,   69,  103,  116,   70,
       71,  143,   72,   73,   74,   75,   75,   75,   75,  135,
      126,   56,   57,  126,  117,  137,  288,   63,  136,   76,
       96,   77,   78,   96,   79,   79,   79,   80,  288,   55,
       56,   57,   55,   81,   57,   81,   57,   57,  285,  284,
       66,   63,   58,   66,   62,  172,   81,  127,  173,  174,
       82,  283,  128,  144,  144,  144,  129,  268,  175,  176,
      130,   58,  176,   83,   84,   75,   75,   75,   75,  178,
       63,  157,  179,  180,  176,  179,   78,  176,   85,   85,

       85,   85,  266,   67,  278,  179,  180,   81,  179,   81,
      176,  277,   86,  176,   75,   75,   75,   75,  179,  180,
       81,  179,  276,  139,   87,  139,   78,  275,   79,   79,
       79,   80,  142,  142,  142,  142,  139,   81,  238,   81,
      140,  238,   78,  274,   80,   80,   80,   80,  215,  216,
       81,  215,  273,   81,   82,   81,  141,  238,  141,  268,
      238,  142,  142,  142,  142,  266,   81,  218,  218,  218,
       82,  126,   56,   57,  126,  183,  272,  183,  264,  272,
      184,  184,  184,  184,  142,  142,  142,  142,  186,  187,
      187,  187,  187,  184,  184,  184,  184,  184,  184,  184,

      184,  215,  216,   58,  215,  263,  236,  237,  127,  236,
      185,  215,  216,  128,  215,  188,  262,  129,  261,  236,
      237,  130,  236,  217,  186,  187,  187,  187,  187,  242,
      242,  242,  242,  236,  237,  238,  236,  268,  238,  242,
      242,  242,  242,  272,  268,  268,  272,  279,  280,  272,
      279,  188,  272,  279,  280,  243,  279,  260,  255,  286,
      280,  270,  286,  286,  280,  243,  286,  271,  270,  281,
      259,  258,  257,  256,  271,  271,  240,  235,  252,  251,
      250,  249,  248,  247,  270,  246,  245,  244,  270,  241,
      271,  240,  235,  233,  271,   61,   61,   61,   61,   61,

       64,   64,   64,   64,   64,   95,   95,   95,  145,  145,
      210,  232,  210,  210,  210,  213,  213,  213,  213,  213,
      234,  234,  234,  234,  234,  239,  239,  239,  239,  239,
      253,  253,  253,  253,  253,  254,  231,  254,  254,  254,
      265,  265,  265,  265,  265,  267,  267,  267,  267,  267,
      269,  269,  269,  269,  269,  282,  230,  282,  282,  282,
      287,  287,  287,  287,  287,  229,  228,  227,  226,  225,
      224,  223,  222,  221,  220,  219,  186,  214,  212,  211,
      209,  208,  207,  206,  205,  204,  203,  202,  201,  200,
      199,  198,  197,  196,  195,  194,  193,  192,  191,  190,

      189,  182,  181,  177,  171,  170,  169,  168,  167,  166,
      165,  164,  163,  162,  161,  160,  159,  158,  157,  156,
      155,  154,  153,  152,  151,  150,  149,  148,  147,  146,
      289,   84,  138,   65,  132,  125,  124,  123,  118,  115,
      112,  111,  104,   98,   97,   94,   93,   92,   89,   65,
      289,    3,  289,  289,  289,  289,  289,  289,  289,  289,
      289,  289,  289,  289,  289,  289,  289,  289,  289,  289,
      289,  289,  289,  289,  289,  289,  289,  289,  289,  289,
      289,  289,  289,  289,  289,  289,  289,  289,  289,  289,
      289,  289,  289,  289,  289,  289,  289,  289,  289,  289,

      289,  289,  289,  289,  289,  289,  289,  289,  289,  289,
      289,  289,  289,  289
    } ;

static yyconst flex_int16_t yy_chk[615] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    2,    8,    9,    2,    5,    5,    5,    5,
        7,   14,    7,    7,   14,   18,   18,   18,   18,   21,
       21,   26,   31,    8,   26,   30,   34,   33,   39,   41,
        9,   34,   36,   39,   43,   43,   31,   33,    5,    2,

       36,   30,   44,   51,    2,   41,   51,   30,    2,   44,
       53,   61,    2,   53,   14,   15,   15,   51,   54,   15,
       15,  293,   15,   15,   15,   15,   15,   15,   15,   54,
       50,   50,   50,   50,   54,   63,  287,   61,   54,   15,
       96,   15,   16,   96,   16,   16,   16,   16,  282,   55,
       55,   55,   55,   16,   57,   16,   57,   57,  277,  276,
       66,   63,   50,   66,  137,  129,   16,   50,  129,  130,
       16,  274,   50,   84,   84,   84,   50,  267,  130,  131,
       50,   55,  131,   16,   17,   78,   78,   78,   78,  133,
      137,  133,  134,  134,  170,  134,   17,  170,   17,   17,

       17,   17,  265,   66,  263,  173,  173,   17,  173,   17,
      176,  262,   17,  176,   75,   75,   75,   75,  179,  179,
       17,  179,  261,   75,   17,   75,   79,  260,   79,   79,
       79,   79,  141,  141,  141,  141,   75,   79,  212,   79,
       75,  212,   80,  259,   80,   80,   80,   80,  182,  182,
       79,  182,  258,   80,   79,   80,   81,  232,   81,  254,
      232,   81,   81,   81,   81,  253,   80,  186,  186,  186,
       80,  126,  126,  126,  126,  139,  256,  139,  252,  256,
      139,  139,  139,  139,  142,  142,  142,  142,  144,  144,
      144,  144,  144,  183,  183,  183,  183,  184,  184,  184,

      184,  209,  209,  126,  209,  251,  211,  211,  126,  211,
      142,  215,  215,  126,  215,  144,  249,  126,  248,  231,
      231,  126,  231,  184,  187,  187,  187,  187,  187,  218,
      218,  218,  218,  236,  236,  238,  236,  255,  238,  242,
      242,  242,  242,  264,  269,  271,  264,  270,  270,  272,
      270,  187,  272,  279,  279,  218,  279,  247,  238,  281,
      281,  255,  281,  286,  286,  242,  286,  255,  269,  271,
      246,  245,  244,  241,  269,  271,  239,  234,  233,  228,
      227,  226,  224,  223,  281,  222,  221,  219,  286,  214,
      281,  213,  210,  208,  286,  290,  290,  290,  290,  290,

      291,  291,  291,  291,  291,  292,  292,  292,  294,  294,
      295,  207,  295,  295,  295,  296,  296,  296,  296,  296,
      297,  297,  297,  297,  297,  298,  298,  298,  298,  298,
      299,  299,  299,  299,  299,  300,  206,  300,  300,  300,
      301,  301,  301,  301,  301,  302,  302,  302,  302,  302,
      303,  303,  303,  303,  303,  304,  205,  304,  304,  304,
      305,  305,  305,  305,  305,  204,  202,  201,  199,  197,
      196,  195,  194,  192,  190,  189,  188,  181,  178,  177,
      175,  174,  172,  171,  168,  167,  166,  165,  163,  162,
      161,  160,  157,  156,  155,  153,  152,  151,  150,  149,

      148,  136,  135,  132,  128,  127,  125,  124,  123,  121,
      120,  119,  118,  117,  116,  114,  113,  112,  111,  110,
      108,  107,  106,  105,  103,  102,  100,   99,   98,   90,
       88,   87,   73,   64,   52,   47,   46,   45,   42,   40,
       38,   37,   32,   29,   27,   24,   23,   22,   19,   10,
        3,  289,  289,  289,  289,  289,  289,  289,  289,  289,
      289,  289,  289,  289,  289,  289,  289,  289,  289,  289,
      289,  289,  289,  289,  289,  289,  289,  289,  289,  289,
      289,  289,  289,  289,  289,  289,  289,  289,  289,  289,
      289,  289,  289,  289,  289,  289,  289,  289,  289,  289,

      289,  289,  289,  289,  289,  289,  289,  289,  289,  289,
      289,  289,  289,  289
    } ;

extern int yy_flex_debug;
int yy_flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
++(yy_lp); \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "lexer.l"
/* GENIUS Calculator
 * Copyright (C) 1997-2011 Jiri (George) Lebl
 *
 * Author: Jiri (George) Lebl
 *
 * This file is part of Genius.
 *
 * Genius is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#line 22 "lexer.l"
#include "config.h"

#include <glib.h>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include "mpwrap.h"
#include "eval.h"
#include "dict.h"
#include "calc.h"
#include "parse.h"
#include "util.h"
#include "binreloc.h"

int gel_lex_fd[2];
int gel_first_tok = STARTTOK;
gboolean gel_return_ret = FALSE;
int gel_parenth_depth = 0;
gboolean gel_lex_init = TRUE;
extern GSList *gel_parsestack;
static int matrix_entry = 0;
static GSList *matrix_entry_stack = NULL;

/* Ugly warning avoiding */
#define yywrap() 1
#define YY_SKIP_YYWRAP
#ifdef FLEX_SCANNER
int yylex(void);
#endif

#define NO_RET {gel_return_ret = FALSE;}
#define DO_RET { \
	if(!gel_parenth_depth) \
		gel_return_ret = TRUE; \
	else \
		gel_return_ret = FALSE; \
}

static GHashTable *fp_hash = NULL;

void gel_lexer_open(FILE *fp);
void gel_lexer_parse(FILE *fp);
void gel_lexer_close(FILE *fp);

void
gel_lexer_open(FILE *fp)
{
	YY_BUFFER_STATE buf;
	if(!fp_hash)
		fp_hash = g_hash_table_new(NULL, NULL);

	buf = g_hash_table_lookup(fp_hash, fp);
	if(buf)
		return;

	buf = yy_create_buffer(fp,YY_BUF_SIZE);
	g_hash_table_insert(fp_hash, fp, buf);
}

void
gel_lexer_parse(FILE *fp)
{
	YY_BUFFER_STATE buf;

	g_assert(fp_hash);

	buf = g_hash_table_lookup(fp_hash, fp);

	yy_switch_to_buffer(buf);
	yyparse();
}

void
gel_lexer_close(FILE *fp)
{
	YY_BUFFER_STATE buf;

	/* don't close the stdin */
	if(fp == stdin)
		return;

	g_assert(fp_hash);

	buf = g_hash_table_lookup(fp_hash, fp);

	yy_delete_buffer(buf);

	 g_hash_table_remove(fp_hash, fp);
}

#line 855 "lexer.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

yy_size_t yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  );
            if ( ! (yy_state_buf) )
                YY_FATAL_ERROR( "out of dynamic memory in yylex()" );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	{
#line 115 "lexer.l"



	if(gel_lex_init) {
		gel_return_ret = FALSE;
		gel_parenth_depth = 0;
		matrix_entry = 0;
		matrix_entry_stack = NULL;
		gel_lex_init = FALSE;
	}
	
	if(gel_first_tok!=INT_MAX) {
		int i = gel_first_tok;
		gel_first_tok = INT_MAX;
		return i;
	}



#line 1098 "lexer.c"

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 290 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 552 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
					{
					(yy_full_match) = yy_cp;
					break;
					}
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 134 "lexer.l"
; /*comment, ignore*/
	YY_BREAK
case 2:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 136 "lexer.l"
{
			char *s;
			char *end;
			char *dir;
			if(gel_parsestack || gel_parenth_depth) {REJECT;}
			s=strchr(yytext,'<')+1; /*find the beginning*/
			end=strrchr(yytext,'>'); /*find the end*/
			s = gel_unescape_string(s,end,NULL);
			dir = gbr_find_data_dir (DATADIR);
			yylval.id = g_build_filename (dir,
						      "genius",
						      s,
						      NULL);
			g_free (dir);
			g_free(s);
			DO_RET;
			return LOADFILE;
		}
	YY_BREAK
case 3:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 155 "lexer.l"
{
			char *s;
			if(gel_parsestack || gel_parenth_depth) {REJECT;}
			s=strchr(yytext,'d')+1; /*move after the load*/
			/*btw from the above RE we know this will work*/
			while(*s==' ' || *s=='\t')
				s++;
			yylval.id = g_strdup(s);
			DO_RET;
			return LOADFILE_GLOB;
		}
	YY_BREAK
case 4:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 167 "lexer.l"
{
			char *s;
			if(gel_parsestack || gel_parenth_depth) {REJECT;}
			s=strchr(yytext,'d')+1; /*move after the cd*/
			/*btw from the above RE we know this will work*/
			while(*s==' ' || *s=='\t')
				s++;
			yylval.id = g_strdup(s);
			DO_RET;
			return CHANGEDIR;
		}
	YY_BREAK
case 5:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 179 "lexer.l"
{
			char *s;
			if(gel_parsestack || gel_parenth_depth) {REJECT;}
			s=strchr(yytext,'n')+1; /*move after the plugin*/
			/*btw from the above RE we know this will work*/
			while(*s==' ' || *s=='\t')
				s++;
			yylval.id = g_strdup(s);
			DO_RET;
			return LOAD_PLUGIN;
		}
	YY_BREAK
case 6:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 191 "lexer.l"
{
			if(gel_parsestack || gel_parenth_depth) {REJECT;}
			DO_RET;
			return PWD;
		}
	YY_BREAK
case 7:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 197 "lexer.l"
{
			char *s;
			if(gel_parsestack || gel_parenth_depth) {REJECT;}
			s=strchr(yytext,'s')+1; /*move after the ls*/
			/*btw from the above RE we know this will work*/
			while(*s==' ' || *s=='\t')
				s++;
			yylval.id = g_strdup(s);
			DO_RET;
			return LS_ARG;
		}
	YY_BREAK
case 8:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 209 "lexer.l"
{
			if(gel_parsestack || gel_parenth_depth) {REJECT;}
			DO_RET;
			return LS;
		}
	YY_BREAK
case 9:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 215 "lexer.l"
{
			char *s;
			if(gel_parsestack || gel_parenth_depth) {REJECT;}
			s=strchr(yytext,'p')+1; /*move after the help*/
			/*btw from the above RE we know this will work*/
			while(*s==' ' || *s=='\t')
				s++;
			yylval.id = g_strdup(s);
			DO_RET;
			return HELP_ARG;
		}
	YY_BREAK
case 10:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 227 "lexer.l"
{
			if(gel_parsestack || gel_parenth_depth) {REJECT;}
			DO_RET;
			return HELP;
		}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 234 "lexer.l"
{
			if (matrix_entry &&
			    GPOINTER_TO_INT(matrix_entry_stack->data) == 0) {
				return NEXTROW;
			}
			DO_RET;
			return SEPAR;
		}
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
#line 243 "lexer.l"
{ 
			DO_RET;
			yylval.id = gel_unescape_string(&yytext[1],NULL,NULL);
			/*kill the trailing "*/
			yylval.id[strlen(yylval.id)-1]='\0';
			return STRING;
		}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 251 "lexer.l"
{ NO_RET; return EQ_CMP; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 252 "lexer.l"
{ NO_RET; return NE_CMP; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 253 "lexer.l"
{ NO_RET; return NE_CMP; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 254 "lexer.l"
{ NO_RET; return CMP_CMP; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 256 "lexer.l"
{ NO_RET; return LE_CMP; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 257 "lexer.l"
{ NO_RET; return GE_CMP; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 259 "lexer.l"
{ NO_RET; return LT_CMP; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 260 "lexer.l"
{ NO_RET; return GT_CMP; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 262 "lexer.l"
{ NO_RET; return EQUALS; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 263 "lexer.l"
{ NO_RET; return DEFEQUALS; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 265 "lexer.l"
{ NO_RET; return SWAPWITH; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 266 "lexer.l"
{ NO_RET; return INCREMENT; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 268 "lexer.l"
{ NO_RET; return LOGICAL_NOT; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 269 "lexer.l"
{ NO_RET; return LOGICAL_AND; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 270 "lexer.l"
{ NO_RET; return LOGICAL_XOR; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 271 "lexer.l"
{ NO_RET; return LOGICAL_OR; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 273 "lexer.l"
{ NO_RET; return WHILE; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 274 "lexer.l"
{ NO_RET; return UNTIL; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 275 "lexer.l"
{ NO_RET; return FOR; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 276 "lexer.l"
{ NO_RET; return SUM; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 277 "lexer.l"
{ NO_RET; return PROD; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 278 "lexer.l"
{ NO_RET; return DO; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 279 "lexer.l"
{ NO_RET; return TO; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 280 "lexer.l"
{ NO_RET; return BY; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 281 "lexer.l"
{ NO_RET; return IN; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 282 "lexer.l"
{ NO_RET; return IF; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 283 "lexer.l"
{ NO_RET; return THEN; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 284 "lexer.l"
{ NO_RET; return ELSE; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 286 "lexer.l"
{ NO_RET; return FUNCTION; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 287 "lexer.l"
{ NO_RET; return PARAMETER; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 288 "lexer.l"
{ NO_RET; return CALL; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 290 "lexer.l"
{ NO_RET; return RETURNTOK; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 291 "lexer.l"
{ DO_RET; return BAILOUT; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 292 "lexer.l"
{ DO_RET; return EXCEPTION; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 293 "lexer.l"
{ DO_RET; return CONTINUE; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 294 "lexer.l"
{ DO_RET; return BREAK; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 296 "lexer.l"
{ NO_RET; return MOD; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 298 "lexer.l"
{ DO_RET; return '.'; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 300 "lexer.l"
{ DO_RET; return LOCAL; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 302 "lexer.l"
{
			gel_parenth_depth++;
			if (matrix_entry_stack != NULL)
				matrix_entry_stack->data =
					GINT_TO_POINTER
					  (GPOINTER_TO_INT(matrix_entry_stack->data) + 1);
			NO_RET;
			return AT;
		}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 311 "lexer.l"
{
			NO_RET;
			return THREEDOTS;
		}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 316 "lexer.l"
{
			matrix_entry++;
			gel_parenth_depth++;
			matrix_entry_stack =
				g_slist_prepend (matrix_entry_stack,
						 GINT_TO_POINTER (0));
			NO_RET;
			return '[';
		}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 326 "lexer.l"
{
			GSList *li;
			matrix_entry--;
			gel_parenth_depth--;
			li = matrix_entry_stack;
			matrix_entry_stack = g_slist_remove_link (matrix_entry_stack, li);
			g_slist_free_1 (li);
			DO_RET;
			return ']';
		}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 338 "lexer.l"
{
			gel_parenth_depth++;
			if (matrix_entry_stack != NULL)
				matrix_entry_stack->data =
					GINT_TO_POINTER
					  (GPOINTER_TO_INT(matrix_entry_stack->data) + 1);
			NO_RET;
			return yytext[0];
		}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 348 "lexer.l"
{
			gel_parenth_depth--;
			if (matrix_entry_stack != NULL)
				matrix_entry_stack->data =
					GINT_TO_POINTER
					  (GPOINTER_TO_INT(matrix_entry_stack->data) - 1);
			DO_RET;
			return MAKEIMAGPARENTH;
		}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 358 "lexer.l"
{
			gel_parenth_depth--;
			if (matrix_entry_stack != NULL)
				matrix_entry_stack->data =
					GINT_TO_POINTER
					  (GPOINTER_TO_INT(matrix_entry_stack->data) - 1);
			DO_RET;
			return yytext[0];
		}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 368 "lexer.l"
{
				/* identifier*/
				yylval.id = g_strdup(yytext);
				DO_RET;
				return FUNCID;
			}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 375 "lexer.l"
{
			mpw_init(yylval.val);
			mpw_set_str(yylval.val,yytext,10);
			DO_RET;
			return NUMBER;
		}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 382 "lexer.l"
{
			mpw_init(yylval.val);
			mpw_set_str_complex_int(yylval.val,yytext,10);
			DO_RET;
			return NUMBER;
		}
	YY_BREAK
case 62:
#line 391 "lexer.l"
case 63:
#line 392 "lexer.l"
case 64:
YY_RULE_SETUP
#line 392 "lexer.l"
{
			char *s;
			if(yytext[0] == '.')
				s = g_strconcat("0",&yytext[0],NULL);
			else
				s = g_strdup(yytext);
			mpw_init(yylval.val);
			mpw_set_str_complex(yylval.val,s,10);
			g_free(s);
			DO_RET;
			return NUMBER;
		}
	YY_BREAK
case 65:
#line 407 "lexer.l"
case 66:
#line 408 "lexer.l"
case 67:
YY_RULE_SETUP
#line 408 "lexer.l"
{
			char *s;
			if(yytext[0] == '.')
				s = g_strconcat("0",&yytext[0],NULL);
			else
				s = g_strdup(yytext);
			mpw_init(yylval.val);
			mpw_set_str_float(yylval.val,s,10);
			g_free(s);
			DO_RET;
			return NUMBER;
		}
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 422 "lexer.l"
{
			char *s;
			int base;

			s=g_malloc(strlen(yytext)-2); /*minus 3 and plus 1*/
			sscanf(yytext,"%d\\%[0-9a-zA-Z]s",&base,s);
			if(base>36) { g_free(s); REJECT; }
			mpw_init(yylval.val);
			mpw_set_str_int(yylval.val,s,base);
			g_free(s);
			DO_RET;
			return NUMBER;
		}
	YY_BREAK
case 69:
#line 437 "lexer.l"
case 70:
#line 438 "lexer.l"
case 71:
YY_RULE_SETUP
#line 438 "lexer.l"
{
			mpw_init(yylval.val);
			mpw_set_str_int(yylval.val,yytext,0);
			DO_RET;
			return NUMBER;
		}
	YY_BREAK
case 72:
/* rule 72 can match eol */
YY_RULE_SETUP
#line 445 "lexer.l"
{ gel_incr_file_info(); }
	YY_BREAK
case 73:
/* rule 73 can match eol */
YY_RULE_SETUP
#line 447 "lexer.l"
{ 
			gel_incr_file_info();
			if(matrix_entry) {
				return NEXTROW;
			} else if(gel_return_ret) {
				gel_first_tok = 0;
				return '\n';
			}
		}
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 457 "lexer.l"
; /*ignore whitespace*/
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 459 "lexer.l"
{ DO_RET; return ELTELTPLUS; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 460 "lexer.l"
{ DO_RET; return ELTELTMINUS; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 461 "lexer.l"
{ DO_RET; return ELTELTMUL; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 462 "lexer.l"
{ DO_RET; return ELTELTDIV; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 463 "lexer.l"
{ DO_RET; return ELTELTBACKDIV; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 464 "lexer.l"
{ DO_RET; return ELTELTMOD; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 465 "lexer.l"
{ DO_RET; return ELTELTEXP; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 466 "lexer.l"
{ DO_RET; return TRANSPOSE; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 468 "lexer.l"
{ DO_RET; return DOUBLEFACT; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 470 "lexer.l"
{
			DO_RET;
			return yytext[0];
		}
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 475 "lexer.l"
{ NO_RET; return yytext[0]; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 477 "lexer.l"
{ DO_RET; return '.'; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 479 "lexer.l"
{ DO_RET; return '|'; }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
#line 481 "lexer.l"
{
			gel_got_eof = TRUE;
			return '\n';
		}
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 486 "lexer.l"
{ NO_RET; return yytext[0]; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 488 "lexer.l"
ECHO;
	YY_BREAK
#line 1835 "lexer.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 290 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    
	register YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 290 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 289);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

		return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register yy_size_t number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    yyfree ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 487 "lexer.l"



int my_yyinput(void);
int my_yyinput(void) { return input(); }

/* avoid unused warnings, kind of bogus */
/* Apparently this no worky, so don't do it */
#if 0
#ifdef FLEX_SCANNER
void fake_fake_fake (void);
void fake_fake_fake (void) {
	 yy_flex_realloc (NULL, 0);
	 yyunput (0, NULL);
}
#endif
#endif

/* Dropping support for tabs as separators in matrix entry as of 1.0.1
   if we want to readd it, just add the following after "ignore whitespace"
   line above
^[\t ][\t ]*	;

[\t ]*,[\t ]*	{ return ','; }

[\t][\t ]*	{
			if(matrix_entry)
				return ',';
		}
		*/


